@@ -1,24 +1,8 @@
 /*
-    Copyright (C) 2010 by BetterInbox <contact@betterinbox.com>
-    Original author: Gregory Schlomoff <greg@betterinbox.com>
+    SPDX-FileCopyrightText: 2010 BetterInbox <contact@betterinbox.com>
+    SPDX-FileContributor: Gregory Schlomoff <greg@betterinbox.com>
 
-    Permission is hereby granted, free of charge, to any person obtaining a copy
-    of this software and associated documentation files (the "Software"), to deal
-    in the Software without restriction, including without limitation the rights
-    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-    copies of the Software, and to permit persons to whom the Software is
-    furnished to do so, subject to the following conditions:
-
-    The above copyright notice and this permission notice shall be included in
-    all copies or substantial portions of the Software.
-
-    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-    THE SOFTWARE.
+    SPDX-License-Identifier: MIT
 */
 
 #ifndef DECLARATIVEDROPAREA_H
@@ -31,6 +15,7 @@ class DeclarativeDragDropEvent;
 class DeclarativeDropArea : public QQuickItem
 {
     Q_OBJECT
+    QML_NAMED_ELEMENT(DropArea)
 
     /**
      * If false the area will receive no drop events
@@ -38,14 +23,14 @@ class DeclarativeDropArea : public QQuickItem
     Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged)
 
     /**
-     * 
+     *
      */
     Q_PROPERTY(bool preventStealing READ preventStealing WRITE setPreventStealing NOTIFY preventStealingChanged)
 
-    Q_PROPERTY(bool containsDrag READ containsDrag NOTIFY containsDragChanged )
+    Q_PROPERTY(bool containsDrag READ containsDrag NOTIFY containsDragChanged)
 
 public:
-    DeclarativeDropArea(QQuickItem *parent=nullptr);
+    DeclarativeDropArea(QQuickItem *parent = nullptr);
     bool isEnabled() const;
     void setEnabled(bool enabled);
 
@@ -59,14 +44,14 @@ Q_SIGNALS:
      * @param event description of the dragged content
      * @see DeclarativeDragDropEvent
      */
-    void dragEnter(DeclarativeDragDropEvent* event);
+    void dragEnter(DeclarativeDragDropEvent *event);
 
     /**
      * Emitted when the mouse cursor dragging something leaves the drag area
      * @param event description of the dragged content
      * @see DeclarativeDragDropEvent
      */
-    void dragLeave(DeclarativeDragDropEvent* event);
+    void dragLeave(DeclarativeDragDropEvent *event);
 
     /**
      * Emitted when the mouse cursor dragging something moves over the drag area
@@ -80,9 +65,9 @@ Q_SIGNALS:
      * @param event description of the dragged content
      * @see DeclarativeDragDropEvent
      */
-    void drop(DeclarativeDragDropEvent* event);
+    void drop(DeclarativeDragDropEvent *event);
 
-    //Notifiers
+    // Notifiers
     void enabledChanged();
 
     void preventStealingChanged();
@@ -109,4 +94,3 @@ private:
 };
 
 #endif
-
